`xotl.tools.decorator`:mod: - Several decorators
================================================

.. module:: xotl.tools.decorator

.. deprecated:: 3.3.0

   This entire package is deprecated since 3.3.0.  It will be removed in
   3.4.0.


Sub packages
------------

.. toctree::
   :glob:
   :maxdepth: 1

   decorator/*
